.. _pubs:

Publications using fwdpy11
======================================================================

This is a bit of a cheat, but the following publications used fwdpy_, which was a precursor to fwdpy11 and informed much
of its design:

* `Sanjak et al. (2017) A Model of Compound Heterozygous, Loss-of-Function Alleles Is Broadly Consistent with
  Observations from Complex-Disease GWAS Datasets <http://journals.plos.org/plosgenetics/article?id=10.1371/journal.pgen.1006573>`_

.. _fwdpy: https://github.com/molpopgen/fwdpy

Other publications that we are aware of. (Please send us yours!)

* `Zhou et al. (PNAS) Evolutionary genomics of grape (Vitis vinifera ssp. vinifera) domestication.
  <http://www.pnas.org/content/114/44/11715.full>`_
* `Schrider and Kern (bioRxiv) Soft sweeps are the dominant mode of adaptation in the human genome.
  <http://biorxiv.org/content/biorxiv/early/2017/04/27/090084.full.pdf>`_
* `Thornton (bioRxiv) Polygenic adaptation to an environmental shift: temporal dynamics of variation under Gaussian
  stabilizing selection and additive effects on a single trait <https://www.biorxiv.org/content/10.1101/505750v1>`_
* `Torres et al. (bioRxiv) The temporal dynamics of background selection in non-equilibrium populations <https://www.biorxiv.org/content/biorxiv/early/2019/04/25/618389.full.pdf>`_
